############
Config Files
############

ROMSearch is controlled primarily through a number of .yml files, which makes extending its functionality simple
without having to delve deep into the code. Here is a comprehensive list of those config files, along with arguments
for each for those who may want to extend ROMSearch's capabilities.

.. toctree::
  :glob:
  :titlesonly:
  :maxdepth: 2

  configs/config
  configs/platforms
  configs/dats
  configs/clonelists
  configs/regex
  configs/defaults